# Py-Research

[![PyPI - Version](https://img.shields.io/pypi/v/py-research)](https://pypi.org/project/py-research)
[![Docs](https://github.com/cloudlane-one/py-research/actions/workflows/docs.yml/badge.svg)](https://cloudlane-one.github.io/py-research)
[![Tests](https://github.com/cloudlane-one/py-research/actions/workflows/lint-and-test.yml/badge.svg)](https://github.com/cloudlane-one/py-research/actions/workflows/lint-and-test.yml)
[![Build](https://github.com/cloudlane-one/py-research/actions/workflows/release.yml/badge.svg)](https://github.com/cloudlane-one/py-research/actions/workflows/release.yml)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Codecov](https://codecov.io/gh/cloudlane-one/py-research/graph/badge.svg?token=J8GLAWTPWX)](https://codecov.io/gh/cloudlane-one/py-research)
[![CodeFactor](https://www.codefactor.io/repository/github/cloudlane-one/py-research/badge)](https://www.codefactor.io/repository/github/cloudlane-one/py-research)
[![CodeClimate Maintainability](https://api.codeclimate.com/v1/badges/4cc310489b325e793d1d/maintainability)](https://codeclimate.com/github/cloudlane-one/py-research/maintainability)

## About this project

This package contains multiple, related but not necessarily interdependent, modules meant to aid with automating and simplifying typical R&D coding workflows in Python.

## How to install

This package is available on PyPI:

```bash
pip install py-research
```

Alternatively, you can install it directly from git via:

```bash
pip install git+https://github.com/cloudlane-one/py-research.git
```

## Contents

```{toctree}
docs/ref-api/index
```

## Indices and Tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
